@@ -6,9 +6,11 @@ use PhpAmqpLib\Channel\AMQPChannel;
 use PhpAmqpLib\Exception\AMQPConnectionClosedException;
 use PhpAmqpLib\Exception\AMQPHeartbeatMissedException;
 use PhpAmqpLib\Exception\AMQPInvalidFrameException;
+use PhpAmqpLib\Exception\AMQPIOException;
 use PhpAmqpLib\Exception\AMQPNoDataException;
 use PhpAmqpLib\Exception\AMQPProtocolConnectionException;
 use PhpAmqpLib\Exception\AMQPRuntimeException;
+use PhpAmqpLib\Exception\AMQPSocketException;
 use PhpAmqpLib\Exception\AMQPTimeoutException;
 use PhpAmqpLib\Wire\AMQPReader;
 use PhpAmqpLib\Wire\AMQPTable;
@@ -162,7 +164,7 @@ class AbstractConnection extends AbstractChannel
         $login_response = null,
         $locale = 'en_US',
         AbstractIO $io,
-        $heartbeat = 60,
+        $heartbeat = 0,
         $connection_timeout = 0,
         $channel_rpc_timeout = 0.0
     ) {
@@ -222,6 +224,8 @@ class AbstractConnection extends AbstractChannel
                 $this->input = new AMQPReader(null, $this->io);
 
                 $this->write($this->amqp_protocol_header);
+                // assume frame was sent successfully, used in $this->wait_channel()
+                $this->last_frame = microtime(true);
                 $this->wait(array($this->waitHelper->get_wait('connection.start')),false,$this->connection_timeout);
                 $this->x_start_ok(
                     $this->getLibraryProperties(),
@@ -599,11 +603,11 @@ class AbstractConnection extends AbstractChannel
         // Keeping the original timeout unchanged.
         $_timeout = $timeout;
         while (true) {
-            $now = time();
+            $start = microtime(true);
             try {
                 list($frame_type, $frame_channel, $payload) = $this->wait_frame($_timeout);
             } catch (AMQPTimeoutException $e) {
-                if ( $this->heartbeat && microtime(true) - ($this->heartbeat*2) > $this->last_frame ) {
+                if ($this->heartbeat && $this->last_frame && microtime(true) - ($this->heartbeat * 2) > $this->last_frame) {
                     $this->debug->debug_msg("missed server heartbeat (at threshold * 2)");
                     $this->setIsConnected(false);
                     throw new AMQPHeartbeatMissedException("Missed server heartbeat");
@@ -618,7 +622,7 @@ class AbstractConnection extends AbstractChannel
                 // skip heartbeat frames and reduce the timeout by the time passed
                 $this->debug->debug_msg("received server heartbeat");
                 if($_timeout > 0) {
-                    $_timeout -= time() - $now;
+                    $_timeout -= $this->last_frame - $start;
                     if($_timeout <= 0) {
                         // If timeout has been reached, throw the exception without calling wait_frame
                         throw new AMQPTimeoutException("Timeout waiting on channel");
@@ -626,26 +630,25 @@ class AbstractConnection extends AbstractChannel
                 }
                 continue;
 
-            } else {
+            }
 
-                if ($frame_channel == $channel_id) {
-                    return array($frame_type, $payload);
-                }
+            if ($frame_channel == $channel_id) {
+                return array($frame_type, $payload);
+            }
 
-                // Not the channel we were looking for.  Queue this frame
-                //for later, when the other channel is looking for frames.
-                // Make sure the channel still exists, it could have been
-                // closed by a previous Exception.
-                if (isset($this->channels[$frame_channel])) {
-                    array_push($this->channels[$frame_channel]->frame_queue, array($frame_type, $payload));
-                }
+            // Not the channel we were looking for.  Queue this frame
+            //for later, when the other channel is looking for frames.
+            // Make sure the channel still exists, it could have been
+            // closed by a previous Exception.
+            if (isset($this->channels[$frame_channel])) {
+                array_push($this->channels[$frame_channel]->frame_queue, array($frame_type, $payload));
+            }
 
-                // If we just queued up a method for channel 0 (the Connection
-                // itself) it's probably a close method in reaction to some
-                // error, so deal with it right away.
-                if (($frame_type == 1) && ($frame_channel == 0)) {
-                    $this->wait();
-                }
+            // If we just queued up a method for channel 0 (the Connection
+            // itself) it's probably a close method in reaction to some
+            // error, so deal with it right away.
+            if ($frame_type == 1 && $frame_channel == 0) {
+                $this->wait();
             }
         }
     }
@@ -922,6 +925,19 @@ class AbstractConnection extends AbstractChannel
         return $this->io;
     }
 
+    /**
+     * Check connection heartbeat if enabled.
+     * @throws AMQPHeartbeatMissedException If too much time passed since last connection activity.
+     * @throws AMQPConnectionClosedException If connection was closed due to network issues or timeouts.
+     * @throws AMQPSocketException If connection was already closed.
+     * @throws AMQPTimeoutException If heartbeat write takes too much time.
+     * @throws AMQPIOException If other connection problems occurred.
+     */
+    public function checkHeartBeat()
+    {
+        $this->io->check_heartbeat();
+    }
+
     /**
      * Handles connection blocked notifications
      *
@@ -1032,13 +1048,13 @@ class AbstractConnection extends AbstractChannel
 
     public static function create_connection($hosts, $options = array()){
         $latest_exception = null;
-        for($i = 0; $i < count($hosts); $i++) {
-            AbstractConnection::validate_host($hosts[$i]);
-            $host = $hosts[$i]['host'];
-            $port = $hosts[$i]['port'];
-            $user = $hosts[$i]['user'];
-            $password = $hosts[$i]['password'];
-            $vhost = isset($hosts[$i]['vhost']) ? $hosts[$i]['vhost'] : "/";
+        foreach ($hosts as $hostdef) {
+            AbstractConnection::validate_host($hostdef);
+            $host = $hostdef['host'];
+            $port = $hostdef['port'];
+            $user = $hostdef['user'];
+            $password = $hostdef['password'];
+            $vhost = isset($hostdef['vhost']) ? $hostdef['vhost'] : "/";
             try {
                 $conn = static::try_create_connection($host, $port, $user, $password, $vhost, $options);
                 return $conn;
